@@ -380,3 +380,36 @@ test_that("checkPermissivePrivacyControlLevel blocks certain functions when not
   )
 
 })
+
+test_that(".listPermittedTidyverseFunctionsDS returns correct default function list ", {
+
+  expect_equal(
+    listPermittedTidyverseFunctionsDS(),
+    c(
+      "everything", "last_col", "group_cols", "starts_with", "ends_with", "contains",
+      "matches", "num_range", "all_of", "any_of", "where", "rename", "mutate", "if_else",
+      "case_when", "mean", "median", "mode", "desc", "last_col", "nth", "where", "num_range",
+      "exp", "sqrt", "scale", "round", "floor", "ceiling", "abs", "sd", "var",
+      "sin", "cos", "tan", "asin", "acos", "atan", "c", "as.character", "as.integer", "as.numeric",
+      "lag", "diff", "cumsum", "is.na"
+    )
+  )
+
+})
+
+test_that(".listPermittedTidyverseFunctionsDS allows functions to be specified via options", {
+
+  options("tidyverse.permitted.functions" = c("function1", "function2"))
+  expect_equal(
+    listPermittedTidyverseFunctionsDS(),
+    c("function1", "function2")
+  )
+
+})
+
+test_that(".check_function_names works with functions which contain a period", {
+
+  options("tidyverse.permitted.functions" = "as.factor")
+  expect_silent(.check_function_names("as.factor(cyl)"))
+
+})
